-- create and select the database
DROP DATABASE IF EXISTS panex_robno;
CREATE DATABASE panex_robno;
USE panex_robno;

-- create the tables for the database
CREATE TABLE partneri (
  kodPartnera        VARCHAR(13) NOT NULL,
  nazivPartnera      VARCHAR(60) NOT NULL,
  mjestoSjedista     VARCHAR(60) NOT NULL,
  ulicaBroj          VARCHAR(60) NOT NULL,
  posPretinac        VARCHAR(10) DEFAULT " ", 
  mjestoPoste        VARCHAR(60) NOT NULL,
  brojPoste          VARCHAR(10) NOT NULL,
  sifraOpcine        INT DEFAULT 0,
  sifraZupanije      INT DEFAULT 0, 
  pokrajina          VARCHAR(50) DEFAULT " ",      
  zemlja             INT DEFAULT 385,
  maticniBroj        VARCHAR(20) DEFAULT " ",
  OIB                INT NOT NULL,   
  telefoni           VARCHAR(50) DEFAULT " ",   
  fax                VARCHAR(34) DEFAULT " ",
  brojBankRacuna     VARCHAR(60) DEFAULT " ",
  emailAddress       VARCHAR(255) DEFAULT " "  NOT NULL,
  password           VARCHAR(20)  DEFAULT "  ", 
  opis               TEXT   NOT NULL,  
  datumOtvaranja     DATETIME NOT NULL,
  datumIzmjene       DATETIME DEFAULT 0,
  tkoJeIzmjenio      VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (kodPartnera),
  UNIQUE INDEX emailAddress (emailAddress)
);

CREATE TABLE narudzbe (
  orderID           INT            NOT NULL   AUTO_INCREMENT,
  customerID        INT            NOT NULL,
  orderDate         DATETIME       NOT NULL,
  shipAmount        DECIMAL(10,2)  NOT NULL,
  taxAmount         DECIMAL(10,2)  NOT NULL,
  shipDate          DATETIME                  DEFAULT NULL,
  shipAddressID     INT            NOT NULL,
  cardType          INT            NOT NULL,
  cardNumber        CHAR(16)       NOT NULL,
  cardExpires       CHAR(7)        NOT NULL,
  billingAddressID  INT            NOT NULL,
  datumOtvaranja    DATETIME NOT NULL,
  datumIzmjene      DATETIME DEFAULT 0,
  tkoJeIzmjenio     VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (orderID), 
  INDEX customerID (customerID)
);

CREATE TABLE narudzbe_stavke (
  itemID            INT            NOT NULL   AUTO_INCREMENT,
  orderID           INT            NOT NULL,
  productID         INT            NOT NULL,
  itemPrice         DECIMAL(10,2)  NOT NULL,
  discountAmount    DECIMAL(10,2)  NOT NULL,
  quantity          INT NOT NULL,
  datumOtvaranja    DATETIME NOT NULL,
  datumIzmjene      DATETIME DEFAULT 0,
  tkoJeIzmjenio     VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (itemID), 
  INDEX orderID (orderID), 
  INDEX productID (productID)
);

CREATE TABLE maticna_robe (
  kodRobe           CHAR(13)       NOT NULL,
  nazivRobe         VARCHAR(100)   NOT NULL, 
  jedinicaMjere     CHAR(3) NOT NULL,
  cijena            DECIMAL(11,3)  NOT NULL,
  popust            DECIMAL(4,2) NOT NULL,  
  kodGrupe          VARCHAR(13) NOT NULL,
  poreznaGrupa      VARCHAR(2) DEFAULT "A" NOT NULL,
  minZaliha         DECIMAL(11,3)  NOT NULL,
  EANkod            VARCHAR(13) DEFAULT " ",
  brutoTezina       DECIMAL(8,2) DEFAULT 0.00,
  netoTezina        DECIMAL(8,2) DEFAULT 0.00,
  zemljaPorijekla   INT  DEFAULT 0,
  zemljaUvoznik     INT DEFAULT 0,
  proOzRobe         VARCHAR(40)	NOT NULL,
  sklopPoKatalogu   VARCHAR(40) DEFAULT " ",
  stavkaSklopa      VARCHAR(20) DEFAULT " ",
  kodProizvodjaca   VARCHAR(13) DEFAULT " ",
  povratnaNaknada   DECIMAL(3,1) DEFAULT 0,
  robaUsluga        CHAR(1) DEFAULT "R" NOT NULL,
  prikazStanja      CHAR(1) DEFAULT "P" NOT NULL,
  opis              TEXT  NOT NULL, 
  datumOtvaranja    DATETIME NOT NULL,
  datumIzmjene      DATETIME DEFAULT 0,
  tkoJeIzmjenio     VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (kodRobe), 
  INDEX poKoduGrupeInazivu(kodGrupe, nazivRobe), 
  INDEX poKoduGrupeIcijeni(kodGrupe, cijena),
  UNIQUE INDEX poProOzRobe (proOzRobe)
);

CREATE TABLE robne_grupe (
  kodGrupe        CHAR(13)      NOT NULL,
  nazivGrupe      VARCHAR(255)   NOT NULL,
  datumOtvaranja    DATETIME NOT NULL,
  datumIzmjene      DATETIME DEFAULT 0,
  tkoJeIzmjenio     VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (kodGrupe)
);
CREATE TABLE stanja (
  kodPoslovnice     CHAR(6)       NOT NULL,
  kodRobe           CHAR(13)      NOT NULL,    
  vrstaProdaje      CHAR(1)       NOT NULL,
  cijena            DECIMAL(11,3)  NOT NULL, 
  stanje            DECIMAL(11,3)  NOT NULL,
  datumInventure    DATETIME DEFAULT 0,
  kolicinaInventure DECIMAL(11,3)  DEFAULT 0,   
  brojInvStavke     INT DEFAULT 0,
  datumOtvaranja    DATETIME NOT NULL,
  datumIzmjene      DATETIME DEFAULT 0,
  tkoJeIzmjenio     VARCHAR(40) DEFAULT " ",   
  PRIMARY KEY (kodPoslovnice, kodRobe, vrstaProdaje, cijena), 
  INDEX poRobi (kodRobe, kodPoslovnice, vrstaProdaje) 
  );
  
CREATE TABLE poslovnice (
  kodPoslovnice      CHAR(6)    NOT NULL,
  nazivPoslovnice    VARCHAR(60) NOT NULL,
  mjestoSjedista     VARCHAR(60) NOT NULL,
  ulicaBroj          VARCHAR(60) NOT NULL,
  posPretinac        VARCHAR(10) DEFAULT " ", 
  mjestoPoste        VARCHAR(60) NOT NULL,
  brojPoste          VARCHAR(10) NOT NULL,
  sifraOpcine        INT DEFAULT 0,
  sifraZupanije      INT DEFAULT 0, 
  pokrajina          VARCHAR(50) DEFAULT " ",      
  zemlja             INT DEFAULT 385,
  maticniBroj        VARCHAR(20) DEFAULT " ",
  OIB                INT NOT NULL,   
  telefoni           TEXT NOT NULL,   
  fax                VARCHAR(34) DEFAULT " ",
  brojBankRacuna     VARCHAR(60) DEFAULT " ",
  emailAddress       VARCHAR(255) DEFAULT " "  NOT NULL,
  password           VARCHAR(20)  DEFAULT " ", 
  datumOtvaranja     DATETIME NOT NULL,
  datumIzmjene       DATETIME DEFAULT 0,
  tkoJeIzmjenio      VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (kodPoslovnice) 
  
);

CREATE TABLE administrators (
  kodAdmin          INT            NOT NULL   AUTO_INCREMENT,
  email             VARCHAR(255)   NOT NULL,
  lozinka           VARCHAR(255)   NOT NULL,
  ime               VARCHAR(255)   NOT NULL,
  prezime           VARCHAR(255)   NOT NULL,
  datumOtvaranja    DATETIME NOT NULL,
  datumIzmjene      DATETIME DEFAULT 0,
  tkoJeIzmjenio     VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (kodAdmin)
);

-- Insert data into the tables


-- Create a user 
GRANT CREATE, SELECT, INSERT, UPDATE, DELETE
ON *
TO panex@localhost
IDENTIFIED BY 'c48kt3';

GRANT SELECT, INSERT, UPDATE, DELETE
ON *
TO panex_javniKoris@localhost
IDENTIFIED BY 'a83bmi';
