<?php
function get_inventuru_po_skladistu ($proda, $vrstaProdaje, $kodGrupe, $kojaStanja, $poreznaGrupa, $brojInvStavkeOd=0, $brojInvStavkeDo=9999) {
    global $db;
    $query = "
select s.proda,
`brojInvStavke`,
s.kodRobe, 
m.`nazivRobe`, 
`vrstaProdaje`, 
m.`jedinicaMjere`,
`kodGrupe`,
s.cijena, 
PDV, 
round(s.cijena*(PDV/100),2) as iznosPDV, 
round(s.cijena*(1+PDV/100),2) as cijenaSPDV, 
stanje,
0 as novoStanje
from inv_stanja as s
inner join maticna_robe as m on m.`kodRobe`=s.`kodRobe`
inner join porezi as p on p.poreznaGrupa= m.poreznaGrupa

where s.proda=:proda 
and (trim(:vrstaProdaje)='' or s.vrstaProdaje=:vrstaProdaje)
and (trim(:poreznaGrupa)='' or p.poreznaGrupa=:poreznaGrupa)
and (trim(:kodGrupe)='' or m.kodGrupe=:kodGrupe)
and (trim(:kojaStanja)='' 
    or (:kojaStanja='+-' and s.stanje<>0)
    or (:kojaStanja='0' and s.stanje=0)
    or (:kojaStanja='+' and s.stanje>0)
    or (:kojaStanja='-' and s.stanje<0)
    )
and brojInvStavke between :brojInvStavkeOd and :brojInvStavkeDo

order by `brojInvStavke`, s.kodRobe, vrstaProdaje
;";
    try {
        $statement = $db->prepare($query);
        
        $statement->bindValue(':proda', $proda);
        $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
        $statement->bindValue(':brojInvStavkeOd', $brojInvStavkeOd);
        $statement->bindValue(':brojInvStavkeDo', $brojInvStavkeDo);
        $statement->bindValue(':kodGrupe', $kodGrupe);
        $statement->bindValue(':kojaStanja', $kojaStanja);
        $statement->bindValue(':poreznaGrupa', $poreznaGrupa);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function update_inv_stanja($proda, $kodRobe, $vrstaProdaje, $cijena, $stanje) {
    global $db;
    $email_user = $_SESSION['admin']['email'];
    $query = 'UPDATE inv_stanja
              SET stanje = :stanje,
              kolicinaInventure = :stanje,
              datumIzmjene = NOW(),
              tkoJeIzmjenio = :email_user
            WHERE proda = :proda 
            AND kodRobe = :kodRobe 
            AND vrstaProdaje = :vrstaProdaje
            AND cijena = :cijena
            ';

    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':proda', $proda);
        $statement->bindValue(':kodRobe', $kodRobe);
        $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
        $statement->bindValue(':cijena', str_replace(',', '.',$cijena));
        $statement->bindValue(':stanje', str_replace(',', '.',$stanje));
        $statement->bindValue(':email_user', $email_user);
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
 
}

function delete_inv_stanja($proda, $kodRobe, $vrstaProdaje, $cijena) {
    global $db;
    $query = 'delete from inv_stanja
            WHERE proda = :proda 
            AND kodRobe = :kodRobe 
            AND vrstaProdaje = :vrstaProdaje
            AND cijena = :cijena
            ';

    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':proda', $proda);
        $statement->bindValue(':kodRobe', $kodRobe);
        $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
        $statement->bindValue(':cijena', str_replace(',', '.',$cijena));
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
 
}

function add_inv_stanja($proda, $kodRobe, $vrstaProdaje, $cijena, $stanje, $brojInvStavke,$datumInventure) {
    global $db;
    $email_user = $_SESSION['admin']['email'];
    $maks=(int)$brojInvStavke;
    if($maks>0) {
        ;
    }
    else {
        $query = 'select max(brojInvStavke) as maks from inv_stanja where proda=:proda';
        try {
            $statement = $db->prepare($query);
            $statement->bindValue(':proda', $proda);
            $statement->execute();
            $result = $statement->fetch();
            $maks=(int)$result['maks'] +1;
            $statement->closeCursor();
        } catch (PDOException $e) {
            $error_message = $e->getMessage();
            display_db_error($error_message);
        }
    }
    
    $query = 'insert into inv_stanja
                (proda, kodRobe, vrstaProdaje, cijena, stanje, kolicinaInventure, brojInvStavke, datumInventure, tkoJeIzmjenio, datumOtvaranja)
             values
                (:proda, :kodRobe, :vrstaProdaje, :cijena, :stanje, :stanje, :maks, :datumInventure, :email_user, NOW())
            ';

    $datumInventure_d = new DateTime($datumInventure);
    
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':proda', $proda);
        $statement->bindValue(':kodRobe', $kodRobe);
        $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
        $statement->bindValue(':cijena', str_replace(',', '.',$cijena));
        $statement->bindValue(':stanje', str_replace(',', '.',$stanje));
        $statement->bindValue(':maks', $maks);
        $statement->bindValue(':email_user', $email_user);
        $statement->bindValue(':datumInventure', $datumInventure_d->format("Y-m-d H:i:s"));
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
 
}

function get_inv_stanje($proda, $kodRobe, $vrstaProdaje, $cijena) {
    global $db;

    $query = 'select * from inv_stanja
            WHERE proda = :proda 
            AND kodRobe = :kodRobe 
            AND vrstaProdaje = :vrstaProdaje
            AND cijena = :cijena
            ';

    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':proda', $proda);
        $statement->bindValue(':kodRobe', $kodRobe);
        $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
        $statement->bindValue(':cijena', str_replace(',', '.',$cijena));
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
 
}
function invZalihe_staro($proda, $vrstaProdaje, $kodGrupe, $kakoSort, $invDonos, $datumInventure) {  
    global $db;
    ini_set('max_execution_time', 300);
    
    $query = "
    select s.kodRobe, vrstaProdaje, nazivRobe, jedinicaMjere, m.kodGrupe, s.cijena,
    stanje,
    round(s.cijena*(1+PDV/100),2) as cijenaSpdv, PDV,
     if(:kakoSort='po_cijeni',s.cijena,0) as sort_cijena
    from pomocna_stanja as s
    left outer join maticna_robe as m on s.kodRobe= m.kodRobe 
    left outer join porezi as p on m.poreznaGrupa= p.poreznaGrupa
    left outer join robne_grupe as r on m.kodGrupe=r.kodGrupe
 where
 proda=:proda
 and stanje <> 0       
 and (:kodGrupe=''  or m.kodGrupe=:kodGrupe) and robaUsluga = 'R'
 and (:vrstaProdaje='' or vrstaProdaje=:vrstaProdaje)
 order by m.kodGrupe, sort_cijena DESC, CASE :kakoSort
                                          when 'po_nazivu' then nazivRobe                        
                                          when 'po_kodu_robe' then s.kodRobe
                                          -- when 'po_cijeni' then s.cijena
                                         END";       
        $statement = $db->prepare($query);
        $statement->bindValue(':proda', $proda);
        $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
        $statement->bindValue(':kodGrupe', $kodGrupe); 
        $statement->bindValue(':kakoSort', $kakoSort);          
  $statement->execute();
  $result = $statement->fetchAll();
  $statement->closeCursor();
  
  if ($invDonos) {
//ubacivanje iz pomocna_stanja u inv_stanja 
      $insert = "
    INSERT INTO inv_stanja 
    SELECT *
    FROM pomocna_stanja 
    WHERE stanje <> 0;
    ";
     try {      
     $statement = $db->prepare($insert);
     $statement->bindValue(':proda', $proda);
     $statement->execute();
     $rowCount = $statement->rowCount();
     $statement->closeCursor(); 
     echo 'Ubačeno iz pomocna_stanja u inv_stanja' . $rowCount;
     } catch (PDOException $e) {
       $error_message = 'DUPLO! već postoji! ' . $e->getMessage();
       display_db_error($error_message); 
    }     
 
//update brojInvStavke, kolicinaInventure i datumInventure       
      $email_user = $_SESSION['admin']['email'];
      $brs=0;
      foreach ($result as $is) {
       $brs +=1;          
       $kodRobe=$is['kodRobe'];
       $vrstaProdaje=$is['vrstaProdaje'];
       $cijena=$is['cijena'];       
       $kolicinaInventure=$is['stanje'];
       $brojInvStavke=$brs;          
       
       $query = "
         UPDATE inv_stanja
         SET brojInvStavke = :brojInvStavke, kolicinaInventure = :kolicinaInventure, datumInventure = :datumInventure,
             tkoJeIzmjenio = :email_user
         where proda=:proda and kodRobe=:kodRobe and vrstaProdaje=:vrstaProdaje
               and cijena=:cijena";
        $statement = $db->prepare($query);
        $statement->bindValue(':proda', $proda);
        $statement->bindValue(':kodRobe', $kodRobe); 
        $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
        $statement->bindValue(':cijena', $cijena);
        $statement->bindValue(':datumInventure', $datumInventure);
        $statement->bindValue(':kolicinaInventure', $kolicinaInventure);
        $statement->bindValue(':brojInvStavke', $brojInvStavke);
        $statement->bindValue(':email_user', $email_user);    
        $statement->execute();
  //      $rowCount = $statement->rowCount();       
  //      $statement->closeCursor();       
     }
  } 
  return $result;   
}
function invZalihe($proda, $vrstaProdaje, $kodGrupe, $kakoSort, $invDonos, $datumInventure) {  
    global $db;
    ini_set('max_execution_time', 300);
    
    $query = "
    select s.kodRobe, vrstaProdaje, nazivRobe, jedinicaMjere, m.kodGrupe, s.cijena,
    stanje,
    round(s.cijena*(1+PDV/100),2) as cijenaSpdv, PDV,
     if(:kakoSort='po_cijeni',s.cijena,0) as sort_cijena
    from pomocna_stanja as s
    left outer join maticna_robe as m on s.kodRobe= m.kodRobe 
    left outer join porezi as p on m.poreznaGrupa= p.poreznaGrupa
    where
    proda=:proda
    and stanje <> 0       
    and (:kodGrupe=''  or m.kodGrupe=:kodGrupe) and robaUsluga = 'R'
    and (:vrstaProdaje='' or vrstaProdaje=:vrstaProdaje)
    order by m.kodGrupe, sort_cijena DESC,
        CASE :kakoSort
          when 'po_nazivu' then nazivRobe                        
          when 'po_kodu_robe' then s.kodRobe
          -- when 'po_cijeni' then s.cijena
        END";       
  $statement = $db->prepare($query);
  $statement->bindValue(':proda', $proda);
  $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
  $statement->bindValue(':kodGrupe', $kodGrupe); 
  $statement->bindValue(':kakoSort', $kakoSort);          
  $statement->execute();
  $result = $statement->fetchAll();
  $statement->closeCursor();
  
  if ($invDonos) {
//ubacivanje iz pomocna_stanja u inv_stanja 
      $email_user = $_SESSION['admin']['email'];
      /*
      $insert = "
        INSERT INTO inv_stanja 
        SELECT *
        FROM pomocna_stanja 
        WHERE stanje <> 0;
        ";
      */
      $insert = "
        CREATE TEMPORARY TABLE pomocna_stanja_ 
        ( PRIMARY KEY (proda, kodRobe, vrstaProdaje, cijena) )
        AS
        SELECT *
        FROM pomocna_stanja 
        WHERE stanje <> 0;
        ";
      try {      
         $statement = $db->prepare($insert);
         $statement->execute();
      } catch (PDOException $e) {
        $error_message = 'Ne mogu kreirati pomoćnu tablicu! ' . $e->getMessage();
        display_db_error($error_message); 
      }     
     
      $insert = "
        insert into inv_stanja 
        (
        proda, kodRobe, vrstaProdaje, cijena, stanje,
        vrsDoPu,proInPu,zapisPu,broDoPu,verziPu,datumPu,rabatPu,absRabatPu,marzaPu,absMarzaPu,zavisniTroskoviPu,absZavisniTroskoviPu,nabavnaCijenaPu,kodPartneraPu,
        vrsDoPi,proInPi,zapisPi,broDoPi,verziPi,datumPi,rabatPopustPi,absRabatPopustPi,
        datumInventure,
        kolicinaInventure,   
        brojInvStavke,
        datumOtvaranja,
        datumIzmjene,  
        tkoJeIzmjenio
        )
        select
        st.proda, st.kodRobe, st.vrstaProdaje, st.cijena, st.stanje,
        vrsDoPu,proInPu,zapisPu,broDoPu,verziPu,datumPu,rabatPu,absRabatPu,marzaPu,absMarzaPu,zavisniTroskoviPu,absZavisniTroskoviPu,nabavnaCijenaPu,kodPartneraPu,
        vrsDoPi,proInPi,zapisPi,broDoPi,verziPi,datumPi,rabatPopustPi,absRabatPopustPi,
        :datumInventure,
        st.stanje, -- kolicinaInventure,   
        t.brojInvStavke,
        datumOtvaranja,
        NOW(),  
        :email_user
        
        from pomocna_stanja as st
        inner join 
        (
        select  inv.*, @brojInvStavke:=@brojInvStavke+1 as brojInvStavke
        from
        (
        select proda, s.kodRobe, vrstaProdaje, nazivRobe, m.kodGrupe, s.cijena,
        stanje,
         if(:kakoSort='po_cijeni',s.cijena,0) as sort_cijena
        from pomocna_stanja_ as s
        left outer join maticna_robe as m on s.kodRobe= m.kodRobe 
         where
         proda=:proda
         and stanje <> 0       
         and (:kodGrupe=''  or m.kodGrupe=:kodGrupe) and robaUsluga = 'R'
         and (:vrstaProdaje='' or vrstaProdaje=:vrstaProdaje)
         order by m.kodGrupe, sort_cijena DESC, 
         CASE :kakoSort
              when 'po_nazivu' then nazivRobe                        
              when 'po_kodu_robe' then s.kodRobe
             END      
        )as inv,
        (SELECT @brojInvStavke:=0) as r
        ) as t on t.proda=st.proda and t.`kodRobe`=st.`kodRobe` and t.`vrstaProdaje`=st.`vrstaProdaje` and t.cijena=st.cijena
        ";
     
     try {      
      $statement = $db->prepare($insert);
      $statement->bindValue(':proda', $proda);
      $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
      $statement->bindValue(':kodGrupe', $kodGrupe); 
      $statement->bindValue(':kakoSort', $kakoSort);          
      $statement->bindValue(':datumInventure', $datumInventure);
      $statement->bindValue(':email_user', $email_user);    
      $statement->execute();
      $rowCount = $statement->rowCount();
      $statement->closeCursor(); 
     echo 'Ubačeno iz pomocna_stanja u inv_stanja' . $rowCount;
     } catch (PDOException $e) {
       $error_message = 'DUPLO! već postoji! ' . $e->getMessage();
       display_db_error($error_message); 
    }     

      $insert = "DROP TABLE pomocna_stanja_  ";
      try {      
         $statement = $db->prepare($insert);
         $statement->execute();
      } catch (PDOException $e) {
        $error_message = 'Ne mogu obrisati pomoćnu tablicu! ' . $e->getMessage();
        display_db_error($error_message); 
      }     
    
   /* 
  //update brojInvStavke, kolicinaInventure i datumInventure       
  $brs=0;
  $query = "
     UPDATE inv_stanja
     SET brojInvStavke = :brojInvStavke, kolicinaInventure = :kolicinaInventure, datumInventure = :datumInventure,
         tkoJeIzmjenio = :email_user
     where proda=:proda and kodRobe=:kodRobe and vrstaProdaje=:vrstaProdaje
           and cijena=:cijena";
  $statement = $db->prepare($query);
  foreach ($result as $is) {
       $brs +=1;          
       $kodRobe=$is['kodRobe'];
       $vrstaProdaje=$is['vrstaProdaje'];
       $cijena=$is['cijena'];       
       $kolicinaInventure=$is['stanje'];
       $brojInvStavke=$brs;          
       
        $statement->bindValue(':proda', $proda);
        $statement->bindValue(':kodRobe', $kodRobe); 
        $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
        $statement->bindValue(':cijena', $cijena);
        $statement->bindValue(':datumInventure', $datumInventure);
        $statement->bindValue(':kolicinaInventure', $kolicinaInventure);
        $statement->bindValue(':brojInvStavke', $brojInvStavke);
        $statement->bindValue(':email_user', $email_user);    
        $statement->execute();
  //      $rowCount = $statement->rowCount();       
  //      $statement->closeCursor();       
     }
    * 
    */
  } 
  return $result;   
}
function brisiInv($proda, $vrstaProdaje) {
     global $db;
     $query = "DELETE FROM inv_stanja
         WHERE proda = :proda AND (:vrstaProdaje = '' OR vrstaProdaje = :vrstaProdaje)"; 
     $statement = $db->prepare($query);
     $statement->bindValue(':proda', $proda);
     $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
     $statement->execute();
     $rowCount = $statement->rowCount();
     $statement->closeCursor();
     return $rowCount;
} 

function rekonstrukcija_stanja_inv($proda, $DVOdo) {
      global $db; 
      //kreiranje temporari fajla
$maketemp = "
    CREATE TEMPORARY TABLE pomocna_stanja (
  proda             VARCHAR(5)       NOT NULL,
  kodRobe           VARCHAR(16)      NOT NULL,    
  vrstaProdaje      CHAR(1)       NOT NULL,
  cijena            DECIMAL(11,3)  NOT NULL, 
  stanje            DECIMAL(11,3)  NOT NULL,
   vrsDoPu     VARCHAR(2) DEFAULT NULL,
   proInPu     VARCHAR(5) DEFAULT NULL,
   zapisPu     VARCHAR(2) DEFAULT NULL,
   broDoPu     INT        DEFAULT NULL,
   verziPu     VARCHAR(3) DEFAULT NULL,
   datumPu     DATETIME   DEFAULT NULL, 
   rabatPu     DECIMAL(11,3) DEFAULT NULL,
   absRabatPu  CHAR(1)    DEFAULT NULL,
   marzaPu     DECIMAL(11,3) DEFAULT NULL,
   absMarzaPu  CHAR(1) DEFAULT NULL,
   zavisniTroskoviPu    DECIMAL(11,3) DEFAULT NULL,
   absZavisniTroskoviPu CHAR(1) DEFAULT NULL,
   nabavnaCijenaPu      DECIMAL(11,3) DEFAULT NULL,
   kodPartneraPu        VARCHAR(13) DEFAULT NULL,
   vrsDoPi           VARCHAR(2) DEFAULT NULL,
   proInPi           VARCHAR(5) DEFAULT NULL,
   zapisPi           VARCHAR(2) DEFAULT NULL,
   broDoPi           INT DEFAULT NULL,
   verziPi           VARCHAR(3) DEFAULT NULL,
   datumPi           DATETIME DEFAULT NULL,
   rabatPopustPi     DECIMAL(11,3) DEFAULT NULL, 
   absRabatPopustPi  CHAR(1) DEFAULT NULL,
  datumInventure    DATETIME DEFAULT 0,
  kolicinaInventure DECIMAL(11,3)  DEFAULT 0,   
  brojInvStavke     INT DEFAULT 0,
  datumOtvaranja    DATETIME NOT NULL,
  datumIzmjene      DATETIME DEFAULT 0,  
  tkoJeIzmjenio     VARCHAR(40) DEFAULT ' ',   
  PRIMARY KEY (proda, kodRobe, vrstaProdaje, cijena), 
  INDEX poRobi (kodRobe, proda, vrstaProdaje) 
  )
  "; 

try {      
     $statement = $db->prepare($maketemp);     
     $statement->execute();
     $rowCount = $statement->rowCount();
      $statement->closeCursor(); 
     } catch (PDOException $e) {
       $error_message = $e->getMessage();
       display_db_error($error_message); 
    }    
$inserttemp = "
    INSERT INTO pomocna_stanja 
    SELECT *
    FROM stanja WHERE proda = :proda  
  ";
try {      
     $statement = $db->prepare($inserttemp);
     $statement->bindValue(':proda', $proda);
     $statement->execute();
     $rowCount = $statement->rowCount();
     $statement->closeCursor(); 
     echo 'Skopirano iz stanja u pomocna_stanja' . $rowCount;
     } catch (PDOException $e) {
       $error_message = $e->getMessage();
       display_db_error($error_message); 
    }     

/*
upisuje onu robu iz prometne koje nema u stanjima
*/     
 
      $query = "
         insert into pomocna_stanja
 (proda, pomocna_stanja.kodRobe, vrstaProdaje, pomocna_stanja.cijena, stanje, datumOtvaranja, tkoJeIzmjenio )
select proda, s.kodrobe, vrstaProdaje, s.cijena , 0 as stanje, now(), 'rekonstrukcija1'
from dok_stavke as s
left outer join vrste_dokumenata as v on v.vrsDo=s.vrsDo
inner join poslovnice as p on p.kodPoslovnice=s.proda
-- left outer join maticna_robe as m on m.kodrobe=s.kodRobe
where (v.tipDokumenta ='R' and s.DVO >=p.datumInventure and s.DVO <= :DVOdo and s.proda = :proda)
-- and m.robaUsluga='R'
and s.kodrobe not in
    (
        select st.kodRobe
        from stanja as st
        where st.proda=s.proda and st.kodRobe=s.kodRobe and st.vrstaProdaje=s.vrstaProdaje and st.cijena=s.cijena
    )
group by proda, s.kodrobe, vrstaProdaje, s.cijena
     ";
try {      
     $statement = $db->prepare($query);
     $statement->bindValue(':proda', $proda);
     $statement->bindValue(':DVOdo', $DVOdo);
     $statement->execute();
     $rowCount = $statement->rowCount();
     $statement->closeCursor();
     echo 'Iz prometnih stavaka u stanja upisano: ' . $rowCount . ' stavki kojih nije bilo u stanja.';
     } catch (PDOException $e) {
       $error_message = $e->getMessage();
       display_db_error($error_message); 
    }        
    
// postavlja sva pomocna_stanja na 0
  $query = "    
       update pomocna_stanja
       set stanje=0
       where proda=:proda";
  try {      
     $statement = $db->prepare($query);
     $statement->bindValue(':proda', $proda);    
     $statement->execute();
     $rowCount = $statement->rowCount();
     $statement->closeCursor();
     echo 'U pomocna_stanja postavljeno na nulu ' . $rowCount . ' stavki.';
     } catch (PDOException $e) {
       $error_message = $e->getMessage();
       display_db_error($error_message); 
    }    

//azuriranje stanja iz stavki dokumenata  
$query = "
 update pomocna_stanja as st 
left outer join
(
select 
    s.proda, 
    s.kodRobe, 
    s.vrstaProdaje, 
    s.cijena, 
    ifnull(sum(ifnull(s.kolicina * v.azurStanja,0)),0) as stanje
from dok_stavke as s
left outer join vrste_dokumenata as v on v.vrsDo=s.vrsDo
inner join poslovnice as p on s.proda=p.kodPoslovnice  
where v.tipDokumenta ='R'
      and s.proda = :proda
      and s.DVO >= p.datumInventure and s.DVO <= :DVOdo
group by s.proda, s.kodrobe, s.vrstaProdaje, s.cijena
)
as s2 
on s2.proda=st.proda and s2.kodRobe=st.kodRobe and s2.vrstaProdaje=st.vrstaProdaje and s2.cijena=st.cijena
set st.stanje= ifnull(s2.stanje,0) + ifnull(kolicinaInventure,0),
    st.datumIzmjene=now(),
    st.tkoJeIzmjenio='rekonstrukcija'   
    where st.proda = :proda
 ";
try {      
     $statement = $db->prepare($query);
     $statement->bindValue(':proda', $proda);
     $statement->bindValue(':DVOdo', $DVOdo);
     $statement->execute();
     $rowCount = $statement->rowCount();
     $statement->closeCursor();
     echo 'U pomocna_stanja ažurirano: ' . $rowCount . ' stavki.';
     } catch (PDOException $e) {
       $error_message = $e->getMessage();
       display_db_error($error_message); 
    }  
    
//Brisanje eventualnih stavki usluga iz pomocna stanja    
$query = "DELETE s.* FROM pomocna_stanja s
         INNER JOIN maticna_robe m ON s.kodRobe = m.kodRobe          
         WHERE  s.proda = :proda AND robaUsluga <> 'R' "; 
     try { 
     $statement = $db->prepare($query);
     $statement->bindValue(':proda', $proda);
     $statement->execute();
     $rowCount = $statement->rowCount();
     $statement->closeCursor();
     echo 'U pomocna_stanja obrisano stavki usluga: ' . $rowCount;
     } catch (PDOException $e) {
       $error_message = $e->getMessage();
       display_db_error($error_message); 
    }  
    
}


function ubaci_pomocna_stanja_i_inv_stanja_u_viski_manjki($proda) {
   global $db; 
   $maketemp = "
    CREATE TEMPORARY TABLE viski_manjki (
  proda             VARCHAR(5)       NOT NULL,   
  kodRobe           VARCHAR(16)      NOT NULL,    
  vrstaProdaje      CHAR(1)       NOT NULL,
  cijena            DECIMAL(11,3)  NOT NULL, 
  knjStanje         DECIMAL(11,3)  NOT NULL,
  invStanje         DECIMAL(11,3)  NOT NULL,
  brojInvStavke     INT DEFAULT 0,
  brojInvStavke_     INT DEFAULT 0,
   PRIMARY KEY (proda, kodRobe, vrstaProdaje, cijena)
)";
try {      
     $statement = $db->prepare($maketemp);     
     $statement->execute();
     $rowCount = $statement->rowCount();
     $statement->closeCursor(); 
     } catch (PDOException $e) {
       $error_message = $e->getMessage();
       display_db_error($error_message); 
    }    
$inserttemp = "
    INSERT INTO viski_manjki 
    (SELECT proda, kodRobe, vrstaProdaje, cijena, stanje, 0, 0, 0
    FROM pomocna_stanja 
    WHERE stanje <> 0)
  ";
    try {      
     $statement = $db->prepare($inserttemp);
     $statement->execute();
     $rowCount = $statement->rowCount();
     $statement->closeCursor(); 
     echo 'Dodano u viski_manjki iz pomocna_stanja' . $rowCount;
     } catch (PDOException $e) {
       $error_message = $e->getMessage();
       display_db_error($error_message); 
    }     
$brisiPomocna = "
    delete 
       from pomocna_stanja
    ";    
     try {      
     $statement = $db->prepare($brisiPomocna); 
     $statement->execute();
     $rowCount = $statement->rowCount();
     $statement->closeCursor(); 
     echo 'Obrisano u pomocna_stanja' . $rowCount;
     } catch (PDOException $e) {
       $error_message = $e->getMessage();
       display_db_error($error_message); 
    }       
   
   $query = "
        UPDATE viski_manjki as v
        INNER JOIN inv_stanja as s
        ON v.proda = s.proda and v.kodRobe = s.kodRobe and v.vrstaProdaje = s.vrstaProdaje and v.cijena = s.cijena
        SET v.invStanje = s.stanje,
            v.brojInvStavke = s.brojInvStavke,
            v.brojInvStavke_ = s.brojInvStavke
        WHERE v.proda = s.proda and v.kodRobe = s.kodRobe and v.vrstaProdaje = s.vrstaProdaje and v.cijena = s.cijena
   ";    
    try {      
     $statement = $db->prepare($query);
     $statement->execute();
     $rowCount = $statement->rowCount();
     echo 'Ažurirano u viski_manjki iz inv_stanja' . $rowCount;
     $statement->closeCursor(); 
     } catch (PDOException $e) {
       $error_message = $e->getMessage();
       display_db_error($error_message); 
    }  
 
    //ubacju se u inv_stavke iz inv_stanja oni kojih nema u inv_stavke
    //radi se kopija viski_manjki jer insert neda (cant reopen ) temporari table(2 puta u queriju neće)
    $maketemp = "
    CREATE TEMPORARY TABLE viski_manjki_ (
  proda             VARCHAR(5)       NOT NULL,   
  kodRobe           VARCHAR(16)      NOT NULL,    
  vrstaProdaje      CHAR(1)       NOT NULL,
  cijena            DECIMAL(11,3)  NOT NULL, 
  knjStanje         DECIMAL(11,3)  NOT NULL,
  invStanje         DECIMAL(11,3)  NOT NULL,
  brojInvStavke     INT DEFAULT 0,
  brojInvStavke_     INT DEFAULT 0,
   PRIMARY KEY (proda, kodRobe, vrstaProdaje, cijena)
)";
try {      
     $statement = $db->prepare($maketemp);     
     $statement->execute();
     $rowCount = $statement->rowCount();
     $statement->closeCursor(); 
     } catch (PDOException $e) {
       $error_message = $e->getMessage();
       display_db_error($error_message); 
    }    
$inserttemp = "
    INSERT INTO viski_manjki_ 
    SELECT *
    FROM viski_manjki   
  ";
    try {      
     $statement = $db->prepare($inserttemp);
     $statement->execute();
     $rowCount = $statement->rowCount();
     $statement->closeCursor(); 
     echo 'Skopirano u viski_manjki_' . $rowCount;
     } catch (PDOException $e) {
       $error_message = $e->getMessage();
       display_db_error($error_message); 
    }    
   
 
//umetanje stavki iz inv_stanja u viski_manjki, kojih nema u viski_manjki    
    $query = "
        insert into viski_manjki 
 (proda, kodRobe, vrstaProdaje, cijena, knjStanje, invStanje, brojInvStavke, brojInvStavke_)
 (
  select s.proda, s.kodRobe, s.vrstaProdaje, s.cijena , 0 as knjStanje, s.stanje, s.brojInvStavke, s.brojInvStavke
        from inv_stanja s
  left join viski_manjki_ v 
        on v.proda = s.proda and v.kodRobe = s.kodRobe and v.vrstaProdaje = s.vrstaProdaje and v.cijena = s.cijena
        WHERE v.proda is NULL
 )
   ";    
    try {      
     $statement = $db->prepare($query);
     $statement->execute();
     $rowCount = $statement->rowCount();
     echo 'Dodano  u viski_manjki iz inv_stanja' . $rowCount;
     $statement->closeCursor(); 
     } catch (PDOException $e) {
       $error_message = $e->getMessage();
       display_db_error($error_message); 
    } 
    $brisiPomocna = "
    delete 
       from viski_manjki_
    ";    
     try {      
     $statement = $db->prepare($brisiPomocna); 
     $statement->execute();
     $rowCount = $statement->rowCount();
     $statement->closeCursor(); 
     echo 'Obrisano u viski_manjki_' . $rowCount;
     } catch (PDOException $e) {
       $error_message = $e->getMessage();
       display_db_error($error_message); 
    } 
    
// treba "upariti" po koduRobe i vrstaProdaje stavke koje su ubačene iz pomocna_stanja a nije ih bilo na inventuri,
// ili su na inventuri sa drugom cijenom pa im je BROJINVSTAVKE = 0  DA BI SE MOGLE SORTIRATI PO BROJINVSTAVKE_  
//stavke iz inv_stanja i pomocna stanja koje pašu po kodRobe vrstaProdaje cijena automatski su uparene.
//to uparivanje omogućava da se izvrši sort viškova-manjkova na isti način kako je rađena inventura - pa je to u konačnici sort po broju inv stavke    
 $query = "   
    select proda, kodRobe, vrstaProdaje, cijena
    FROM viski_manjki
    WHERE brojInvStavke_ = 0   
";
    try {      
     $statement = $db->prepare($query); 
     $statement->execute();
     $result = $statement->fetchAll();
     $statement->closeCursor(); 
     echo 'Pronađeno stavki bez broja invBrojStavke_ u viski_manjki' . count($result);
     } catch (PDOException $e) {
       $error_message = $e->getMessage();
       display_db_error($error_message); 
    } 
    foreach ($result as $b) {
        $proda = $b['proda'];
        $kodRobe = $b['kodRobe'];
        $vrstaProdaje = $b['vrstaProdaje'];
        $cijena = $b['cijena'];
//određivanje za svaku stavku kojoj je invBrojStavke_ = 0 broj odgovarajući (ako ga ima)        
        $query = "
            select * from viski_manjki 
            where proda = :proda and kodRobe = :kodRobe and vrstaProdaje = :vrstaProdaje
                  and brojInvStavke <> 0";  
     try {     
     $statement = $db->prepare($query); 
     $statement->bindValue(':proda', $proda);
     $statement->bindValue(':kodRobe', $kodRobe);
     $statement->bindValue(':vrstaProdaje', $vrstaProdaje);    
     $statement->execute();
     $result = $statement->fetchAll();     
     $statement->closeCursor(); 
      } catch (PDOException $e) {
       $error_message = 'Greška inventura_db linija 468 ' . $e->getMessage();
       display_db_error($error_message); 
     } 
     if (count($result) > 0) { 
//pronašao je bar jednu inv.stavku ili više ako ima više inv stavki za istu robu 
//ako ih je više dovoljno je uzeti prvu  
         $result_ = $result[0];           
         $brojInvStavke = $result_['brojInvStavke'];           
         $query = " UPDATE viski_manjki
               SET brojInvStavke_ = :brojInvStavke
               where proda = :proda and kodRobe = :kodRobe and vrstaProdaje = :vrstaProdaje and cijena = :cijena
          ";     
     $statement = $db->prepare($query); 
     $statement->bindValue(':proda', $proda);
     $statement->bindValue(':kodRobe', $kodRobe);
     $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
     $statement->bindValue(':cijena', $cijena);
     $statement->bindValue(':brojInvStavke', $brojInvStavke);
     $statement->execute();
     $rowCount = $statement->rowCount();
     $statement->closeCursor();  
     }
   } 
   
//Izračun više-niže cijene, prosječne cijene,  višak-manjak
//1.ako postoji samo jedna stavka po kodRobe i vrstaProdaje onda se višak-manjak ispisuje na toj stavki(više-niže cijene nema) ISTE CIJENE, A RAZLIČITE
//ILI ISTE KOLIČINE 
//2. VIŠE STAVKI SA RAZLIČITIM CIJENAMA 
//ako postoji više od 1 stavka (2 i više) onda se ispis VIŠKOVA-MANJKOVA I VIŠE-NIŽE CIJENE
//radi u posebnom redu kao analiza više-niže cijene i viškova-manjkova za više stavki       
//stavke se pišu sa nazivom cijenom invstanje i knj stanje kao kad je jedna stavka. a višak-manjak posebni red
   
}

function stavke_viski_manjki($proda, $vrstaProdaje, $kodGrupe, $kakoSort, $invDonos, $datumInventure) {  
    global $db;
    ini_set('max_execution_time', 300);
    
    $query = "
    select v.kodRobe, vrstaProdaje, nazivRobe, jedinicaMjere, m.kodGrupe, v.cijena,
    invStanje, knjStanje,
    round(v.cijena*(1+PDV/100),2) as cijenaSpdv, PDV,
     if(:kakoSort='po_inv_stavki',v.brojInvStavke_,0) as sort_invStavka, brojInvStavke, brojInvStavke_
--     if(:kakoSort='po_kodu_robe',' ',' ') as kodRobe_, brojInvStavke, brojInvStavke_  
    from viski_manjki as v
    left outer join maticna_robe as m on v.kodRobe= m.kodRobe 
    left outer join porezi as p on m.poreznaGrupa= p.poreznaGrupa
    left outer join robne_grupe as r on m.kodGrupe=r.kodGrupe
 where
 proda=:proda
-- and invStanje <> 0       
 and (:kodGrupe=''  or m.kodGrupe=:kodGrupe) and robaUsluga = 'R'
 and (:vrstaProdaje='' or vrstaProdaje=:vrstaProdaje)
-- order by m.kodGrupe, sort_invStavka, kodRobe, vrstaProdaje, kodRobe_
   order by m.kodGrupe, sort_invStavka, kodRobe, vrstaProdaje, v.cijena
      --        CASE :kakoSort
      --            when 'po_nazivu' then nazivRobe                        
      --            when 'po_kodu_robe' then v.kodRobe
                  -- when 'po_cijeni' then v.cijena
      --        END            
              ";       
        $statement = $db->prepare($query);
        $statement->bindValue(':proda', $proda);
        $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
        $statement->bindValue(':kodGrupe', $kodGrupe); 
        $statement->bindValue(':kakoSort', $kakoSort);          
  $statement->execute();
  $result = $statement->fetchAll();
  $statement->closeCursor();
  return $result;
}
function datum_inventure_iz_inv_stanja($proda) {
//pronalazi datum inventure i vrijeme za određenu prodavaonu
//dovoljno je da  pronađe datum-inventure za prvu stavku - jednu stavku
//ako ih je više onda nije dobro(različiti datumi inventure)    
    global $db;  
    $query = "SELECT DISTINCT datumInventure from inv_stanja
             WHERE proda = :proda and datumInventure IS NOT NULL and datumInventure <> '' and brojInvStavke > 0";
    $statement = $db->prepare($query);
    $statement->bindValue(':proda', $proda);
    $statement->execute();
    $result = $statement->fetch();
    $statement->closeCursor();
    $brojac = count($result);
//    echo '$brojac=' . $brojac;
    if ($brojac == 0) return $datumInventure = ''; 
    $datumInventure = $result[0];
//    echo '$datumInventure' . $datumInventure;
    return $datumInventure;
}
?>