<?php
function get_kontni_moduli() {
    global $db;
    $query = 'SELECT * FROM kontni_moduli'; 
    try {
        $statement = $db->prepare($query);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}
function get_kontni_moduli_bez_stavaka() {
    global $db;
    $query = "select kontniModul, nazivModula from kontni_moduli group by kontniModul, nazivModula"; 
	try {
        $statement = $db->prepare($query);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function get_kontni_modul($kontniModul, $brojStavke) {
    global $db;
    $query = '
        SELECT *
        FROM kontni_moduli
        WHERE kontniModul = :kontniModul AND brojStavke=:brojStavke';
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kontniModul', $kontniModul);
        $statement->bindValue(':brojStavke', $brojStavke);
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function get_kontni_modul_sve_stavke($kontniModul) {
    global $db;
    $query = '
        SELECT *
        FROM kontni_moduli
        WHERE kontniModul = :kontniModul';
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kontniModul', $kontniModul);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}
function get_max_brojStavke($kontniModul) {
    global $db;
    $query = "SELECT IFNULL(MAX(brojStavke),0) as brojStavke FROM kontni_moduli WHERE kontniModul=:kontniModul";    
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kontniModul', $kontniModul);
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return (int)$result[0];
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}
function add_kontni_modul(&$slog) {
    global $db;
    $email_user = $_SESSION['admin']['email'];
    $slog['brojStavke']=get_max_brojStavke($slog['kontniModul'])+1;
    $query = "
        INSERT INTO kontni_moduli
        (
            kontniModul,
            brojStavke,
            nazivModula,
            stoSeKnjizi,
            kontoDugovni,
            kakoSeKnjiziDugovni,
            predznakDugovni,
            kontoPotrazni,
            kakoSeKnjiziPotrazni,
            predznakPotrazni,
            datumOtvaranja,
            tkoJeIzmjenio
        )
        VALUES
        (
            :kontniModul,
            :brojStavke,
            :nazivModula,
            :stoSeKnjizi,
            :kontoDugovni,
            :kakoSeKnjiziDugovni,
            :predznakDugovni,
            :kontoPotrazni,
            :kakoSeKnjiziPotrazni,
            :predznakPotrazni,
            NOW(), 
            :email_user 
        )";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kontniModul', $slog['kontniModul']);
        $statement->bindValue(':brojStavke',  $slog['brojStavke']);
        $statement->bindValue(':nazivModula', $slog['nazivModula']);
        $statement->bindValue(':stoSeKnjizi', $slog['stoSeKnjizi']);
        if(trim($slog['kontoDugovni'])=='')
            $statement->bindValue(':kontoDugovni', null, PDO::PARAM_NULL);
        else
            $statement->bindValue(':kontoDugovni', $slog['kontoDugovni']);
        $statement->bindValue(':kakoSeKnjiziDugovni', $slog['kakoSeKnjiziDugovni']);
        $statement->bindValue(':predznakDugovni', $slog['predznakDugovni']);
        if(trim($slog['kontoPotrazni'])=='')
            $statement->bindValue(':kontoPotrazni', null, PDO::PARAM_NULL);
        else
            $statement->bindValue(':kontoPotrazni', $slog['kontoPotrazni']);
        $statement->bindValue(':kakoSeKnjiziPotrazni', $slog['kakoSeKnjiziPotrazni']);
        $statement->bindValue(':predznakPotrazni', $slog['predznakPotrazni']);

        $statement->bindValue(':email_user', $email_user);
        $statement->execute();
        $statement->closeCursor();
        //return $poreznaGrupa;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function update_kontni_modul($slog) {
    global $db;
	$email_user = $_SESSION['admin']['email'];
    $query = '
        UPDATE kontni_moduli
        SET 
            nazivModula = :nazivModula,
            stoSeKnjizi = :stoSeKnjizi,
            kontoDugovni = :kontoDugovni,
            kakoSeKnjiziDugovni = :kakoSeKnjiziDugovni,
            predznakDugovni = :predznakDugovni,
            kontoPotrazni = :kontoPotrazni,
            kakoSeKnjiziPotrazni = :kakoSeKnjiziPotrazni,
            predznakPotrazni = :predznakPotrazni,
            datumIzmjene = NOW(),
            tkoJeIzmjenio = :email_user
        WHERE kontniModul = :kontniModul AND brojStavke=:brojStavke';
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kontniModul', $slog['kontniModul']);
        $statement->bindValue(':brojStavke', $slog['brojStavke']);
        $statement->bindValue(':nazivModula', $slog['nazivModula']);
        $statement->bindValue(':stoSeKnjizi', $slog['stoSeKnjizi']);
        if(trim($slog['kontoDugovni'])=='')
            $statement->bindValue(':kontoDugovni', null, PDO::PARAM_NULL);
        else
            $statement->bindValue(':kontoDugovni', $slog['kontoDugovni']);
        $statement->bindValue(':kakoSeKnjiziDugovni', $slog['kakoSeKnjiziDugovni']);
        $statement->bindValue(':predznakDugovni', $slog['predznakDugovni']);
        if(trim($slog['kontoPotrazni'])=='')
            $statement->bindValue(':kontoPotrazni', null, PDO::PARAM_NULL);
        else
            $statement->bindValue(':kontoPotrazni', $slog['kontoPotrazni']);
        $statement->bindValue(':kakoSeKnjiziPotrazni', $slog['kakoSeKnjiziPotrazni']);
        $statement->bindValue(':predznakPotrazni', $slog['predznakPotrazni']);
        $statement->bindValue(':email_user', $email_user); 
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function delete_kontni_moduli  ($kontniModul, $brojStavke) {
    global $db;
    $query = '
        DELETE FROM kontni_moduli 
        WHERE kontniModul = :kontniModul AND brojStavke=:brojStavke';
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kontniModul', $kontniModul);
        $statement->bindValue(':brojStavke', $brojStavke);
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}
?>