<?php

function kreiraj_tablicu_za_naljepnice() {
    global $db;
    $query = "
        create  table if not exists roba_za_naljepnice
        ( 
        kodRobe varchar(16) not null,
        tkoJeIzmjenio varchar(40) not null,
        datumOtvaranja datetime,
        PRIMARY KEY (kodRobe, tkoJeIzmjenio)
        )
        ";
    try {      
        $statement = $db->prepare($query);
        $statement->execute();
    } catch (PDOException $e) {
        $error_message = 'Ne mogu kreirati pomoćnu tablicu! ' . $e->getMessage();
        display_db_error($error_message); 
    }
    delete_tablicu_za_naljepnice();
}    

function delete_tablicu_za_naljepnice() {
    global $db;
    $email_user = $_SESSION['admin']['email'];
    $query = "
        delete from roba_za_naljepnice 
        where tkoJeIzmjenio =:email_user
        or date(datumOtvaranja)<>date(now())";
    try {      
        $statement = $db->prepare($query);
        $statement->bindValue(':email_user', $email_user);
        $statement->execute();
    } catch (PDOException $e) {
        $error_message = 'Ne mogu brisati pomoćnu tablicu! ' . $e->getMessage();
        display_db_error($error_message); 
    }     
}

function naljepnice_po_grupi($kodGrupe, $podgrupe) {
    global $db;
    $email_user = $_SESSION['admin']['email'];
    if(trim($podgrupe)!='')
        $kodGrupe=trim($kodGrupe).'%';    
    $query = "
    insert into roba_za_naljepnice
    select kodRobe, :email_user, now()
    from maticna_robe
    where trim(kodGrupe) like :kodGrupe
    ON DUPLICATE KEY UPDATE datumOtvaranja=now() ";
 
    try {      
        $statement = $db->prepare($query);
        $statement->bindValue(':kodGrupe', $kodGrupe);
        $statement->bindValue(':email_user', $email_user);
        $statement->execute();
    } catch (PDOException $e) {
        $error_message = 'Ne mogu kreirati podatke za naljepnice! ' . $e->getMessage();
        display_db_error($error_message); 
    }     
}

function naljepnice_za_odabranu_robu($artikli) {
    global $db;
    $email_user = $_SESSION['admin']['email'];
    $query = "
    insert into roba_za_naljepnice
    (kodRobe, tkoJeIzmjenio, datumOtvaranja) ";
    $v=" values ";
    $valuesDio='';
    try {      
        foreach ($artikli as $kodRobe) {
            $kodRobe=trim($kodRobe);
            if($kodRobe=='')
                continue;
            
            $valuesDio.=$v."('$kodRobe', '$email_user', now())";
            $v=', ';
            //if(is_array(get_product_maticna_robe($kodRobe))) {
              //  $statement->bindValue(':kodRobe', $kodRobe);
            //}
        }
        if($valuesDio=='')
           return false;
        $query.=$valuesDio."      ON DUPLICATE KEY UPDATE datumOtvaranja=now() ";

        $statement = $db->prepare($query);
        $statement->execute();   
    } catch (PDOException $e) {
        $error_message = 'Ne mogu kreirati podatke za naljepnice! ' . $e->getMessage();
        display_db_error($error_message); 
    }     
    
}
function get_naljepnice($proda) {
    global $db;
    $email_user = $_SESSION['admin']['email'];

    $query = "
    select 
    st.proda, st.kodRobe, r.nazivRobe, if(sum(st.stanje)>=1,round(sum(st.stanje),0),1) as brojNaljepnica, 
    sum(st.stanje) as kolicina,  
    round(r.cijena*(1+ PDV/100),2) as cijenaSPorezom, 
    r.cijena,
    r.popust,
    r.jedinicaMjere,
    r.zemljaPorijekla,
    -- ako ima više slogova uzima dokument s največim brodo --> max
    max(if(broDoPu>0 and datumPu>p.datumInventure,
        -- lpad(broDoPu,5,'00000') zbog max stavlja pet vodečih nula i reže broj na pet znakova počevsi s desna
        -- pa tako: 15 postaje 00015, 4670 postaje 04670, 5 postaje 00005 
        concat(lpad(broDoPu,5,'00000'),';',if(st.vrsDoPu=2, 'Int.fa', vd.`nazivDokumenta`),':',
            if(trim(zapisPu)<> '',concat(trim(zapisPu), ' '),''),
            broDoPu, '-', if(st.vrsDoPu=2, proInPu,proda), ';',ifnull(kodPartneraPu,'')
        ,';',st.proda,':',vrsDoPu,':',proInPu,':',zapisPu,':',brodoPu,':', verziPu),    
        concat('00000;Donos:', st.brojInvStavke,'/',year(st.datumInventure), ';','')
    )) as dokument,
    1 as selektirano,
    '' as kodPartnera,
    if(:brojNaljepnica=1,1,if(sum(st.stanje)>=1,round(sum(st.stanje),0),1)) as koliko,
    p.vrstaPoslovnice

    from stanja as st
    join roba_za_naljepnice as n on n.kodRobe=st.kodRobe and n.tkoJeIzmjenio=:korisnik
    join poslovnice as p on p.kodPoslovnice=st.proda
    join maticna_robe as r on r.`kodRobe`=st.`kodRobe`
    join porezi as pdv on pdv.`poreznaGrupa`=r.`poreznaGrupa`
    left outer join vrste_dokumenata as vd on vd.`vrsDo`=st.`vrsDoPu`
    where stanje>0 and r.cijena>0
    and proda=:proda
    group by st.proda, st.kodRobe, r.cijena, r.popust    
";

    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':proda', $proda);
        $statement->bindValue(':brojNaljepnica', $_POST['brojNaljepnica']);
        $statement->bindValue(':korisnik', $email_user);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
    
}