<?php
function get_cijenu_iz_cjenika($proda, $oznakaCjenika, $kodPartnera, $kodRobe, $vrstaProdaje) {
    global $db;
    $query="
        select *
        from posebni_cjenik
        where (oznakaCjenika=:oznakaCjenika or trim(:oznakaCjenika)='')
        and (kodPoslovnice=:kodPoslovnice or trim(:kodPoslovnice)='')
        and kodPartnera=:kodPartnera
        and kodRobe=:kodRobe
        and vrstaProdaje=:vrstaProdaje
        ";
        try {
            $statement = $db->prepare($query);
            $statement->bindValue(':oznakaCjenika', $oznakaCjenika);
            $statement->bindValue(':kodPoslovnice', $proda);
            $statement->bindValue(':kodPartnera', $kodPartnera);
            $statement->bindValue(':kodRobe', $kodRobe);
            $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
            $statement->execute();
            $zapis= $statement->fetch();
            $statement->closeCursor();
            if(is_array($zapis))
                return $zapis['cijena'];
            else
                return null;
        } catch (PDOException $e) {
            $error_message = 'Dohvat cijene iz cjenika get_cijenu_iz_cjenika:'.$e->getMessage();
            display_db_error($error_message);
        }
}   
function get_cijenu_iz_cjenika_po_partneru($proda, $oznakaCjenika, $kodPartnera, $kodRobe, $vrstaProdaje) {
    global $db;
    $query="
        select 1 as zaSort, c.*
        from posebni_cjenik as c 
        left outer join partner as p on p.`kodPartnera`=c.`kodPartnera` 
        where (c.oznakaCjenika=:oznakaCjenika or trim(:oznakaCjenika)='') 
        and (c.kodPoslovnice=:kodPoslovnice or c.kodPoslovnice='0' or trim(:kodPoslovnice)='')
        and c.kodPartnera=:kodPartnera
        and (c.kodRobe=:kodRobe and c.vrstaProdaje=:vrstaProdaje)
        union
        select 2 as zaSort, c.*
        from posebni_cjenik as c        
        join partner as p on p.`oznakaCjenika`=c.`oznakaCjenika` and p.kodPartnera=:kodPartnera
        where (c.oznakaCjenika=:oznakaCjenika or trim(:oznakaCjenika)='') 
        and (c.kodPoslovnice=:kodPoslovnice or c.kodPoslovnice='0' or trim(:kodPoslovnice)='')
        and (c.kodRobe=:kodRobe and c.vrstaProdaje=:vrstaProdaje)
        order by zaSort, kodPoslovnice desc
        limit 1
        ";
        try {
            $statement = $db->prepare($query);
            $statement->bindValue(':oznakaCjenika', $oznakaCjenika);
            $statement->bindValue(':kodPoslovnice', $proda);
            $statement->bindValue(':kodPartnera', $kodPartnera);
            $statement->bindValue(':kodRobe', $kodRobe);
            $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
            $statement->execute();
            $zapis= $statement->fetch();
            $statement->closeCursor();
            if(is_array($zapis))
                return $zapis['cijena'];
            else
                return null;
        } catch (PDOException $e) {
            $error_message = 'Dohvat cijene iz cjenika get_cijenu_iz_cjenika_po_partneru:'.$e->getMessage();
            display_db_error($error_message);
        }
}
function get_cjenici_za_cijenu($kodRobe, $cijena, $proda='', $kodPartnera='', $oznakaCjenika='') {
    global $db;
    $query="
        select * 
        from posebni_cjenik
        where cijena=:cijena and kodRobe=:kodRobe
        and (kodPoslovnice=:kodPoslovnice or trim(:kodPoslovnice)='' or :kodPoslovnice='0')
        and (oznakaCjenika=:oznakaCjenika or trim(:oznakaCjenika)='')
        and (kodPartnera=:kodPartnera or trim(:kodPartnera)='')
        ";
        try {
            $statement = $db->prepare($query);
            $statement->bindValue(':oznakaCjenika', $oznakaCjenika);
            $statement->bindValue(':kodPoslovnice', $proda);
            $statement->bindValue(':kodPartnera', $kodPartnera);
            $statement->bindValue(':kodRobe', $kodRobe);
            $statement->bindValue(':cijena', $cijena);
            $statement->execute();
            $result = $statement->fetchAll();
            $statement->closeCursor();
            return $result;
        } catch (PDOException $e) {
            $error_message = 'Dohvat cijene iz cjenika get_cjenici_za_cijenu:'.$e->getMessage();
            display_db_error($error_message);
        }
}
function obrada_posebnih_cjenika($oznakaCjenika, $nazivCjenika, $primjenaCjenika, $proda, $kodPartnera, $vrstaProdaje, $kodGrupe, $kodRobe, 
                                 $brisiCjenik, $dodUcjenik, $promjenaCijene, $posto, $stavkaOd, $stavkaDo) {
    global $db;
    $obrisano=0;
    $dodanoUCjenik=0;
    $email_user = $_SESSION['admin']['email'];

    if($brisiCjenik) 
        $obrisano=delete_posebni_cjenik ($oznakaCjenika, $proda, $kodPartnera, $kodGrupe, '', $vrstaProdaje);
   
    $cjenik=get_nazivi_cjenika($oznakaCjenika);
    if(empty($cjenik)) {
        if(trim($dodUcjenik)=='')
            return null;
        add_nazivi_cjenika($oznakaCjenika, $nazivCjenika, $primjenaCjenika);
    }
    
    if($dodUcjenik=='M') {
        // iz glavnog cjenika 
        if(trim($kodRobe)!='')
        $query = "  
        insert into posebni_cjenik
        (
        select :kodPoslovnice, :oznakaCjenika, :kodPartnera,
        kodRobe, vrstaProdaje, 
        if(:posto=0, cijena, 
           round(if(:promjenaCijene='S', cijena - cijena*:posto/100, cijena + cijena*:posto/100 ),3)
        ) as cijena,
        now(), null, :email_user
        from maticna_robe as m,
        (
            select '0' as vrstaProdaje
            union
            select '1' as vrstaProdaje
            union
            select '2' as vrstaProdaje
        ) as vp
        where cijena>0
        and (vrstaProdaje=:vrstaProdaje or trim(:vrstaProdaje)='')
        and (kodRobe=:kodRobe or trim(:kodRobe)='')
        and not exists
        (
            select * from posebni_cjenik as pc
            where pc.oznakaCjenika=:oznakaCjenika and pc.kodPoslovnice=:kodPoslovnice and pc.kodPartnera=:kodPartnera
            and (pc.vrstaProdaje=:vrstaProdaje or trim(:vrstaProdaje)='')
            and pc.`kodRobe`=m.`kodRobe` and pc.`vrstaProdaje`=vp.`vrstaProdaje`
        )

        )            
        ";
        else    
        $query = "  
        insert into posebni_cjenik
        (
        select :kodPoslovnice, :oznakaCjenika, :kodPartnera,
        kodRobe, vrstaProdaje, 
        if(:posto=0, cijena, 
           round(if(:promjenaCijene='S', cijena - cijena*:posto/100, cijena + cijena*:posto/100 ),3)
        ) as cijena,
        now(), null, :email_user
        from maticna_robe as m,
        (
            select '0' as vrstaProdaje
            union
            select '1' as vrstaProdaje
            union
            select '2' as vrstaProdaje
        ) as vp
        where cijena>0
        and (vrstaProdaje=:vrstaProdaje or trim(:vrstaProdaje)='')
        and (kodGrupe=:kodGrupe or trim(:kodGrupe)='')
        and not exists
        (
            select * from posebni_cjenik as pc
            where pc.oznakaCjenika=:oznakaCjenika and pc.kodPoslovnice=:kodPoslovnice and pc.kodPartnera=:kodPartnera
            and (pc.vrstaProdaje=:vrstaProdaje or trim(:vrstaProdaje)='')
            and pc.`kodRobe`=m.`kodRobe` and pc.`vrstaProdaje`=vp.`vrstaProdaje`
        )

        )            
        ";
        try {
            $statement = $db->prepare($query);
            $statement->bindValue(':oznakaCjenika', $oznakaCjenika);
            $statement->bindValue(':kodPoslovnice', $proda);
            $statement->bindValue(':kodPartnera', $kodPartnera);
            if(trim($kodRobe)!='')
                $statement->bindValue(':kodRobe', $kodRobe);
            else    
                $statement->bindValue(':kodGrupe', $kodGrupe);
            $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
            $statement->bindValue(':posto', $posto);
            $statement->bindValue(':promjenaCijene', $promjenaCijene);
            $statement->bindValue(':email_user', $email_user);
            $statement->execute();
            $dodanoUCjenik = $statement->rowCount();
            $statement->closeCursor();
            unset($statement);
        } catch (PDOException $e) {
            $error_message = 'Kreiranje cjenika:'.$e->getMessage();
            display_db_error($error_message);
        }
        
    }
    else if($dodUcjenik=='S') {
        // iz stanja
        if(trim($kodRobe)!='')
        $query = "
        insert into posebni_cjenik
        (
        select :kodPoslovnice, :oznakaCjenika, :kodPartnera,
        s.kodRobe, s.vrstaProdaje, 
        if(:posto=0, s.cijena, 
           round(if(:promjenaCijene='S', s.cijena - s.cijena*:posto/100, s.cijena + s.cijena*:posto/100 ),3)
        ) as cijena,
        now(), null, :email_user
        from 
        (
            select proda, kodRobe, vrstaProdaje, 
            -- prosječna cijena
            round(sum(cijena*if(stanje>0,stanje,kolicinaInventure))/sum(if(stanje>0,stanje,kolicinaInventure)),3) as cijena 
            from stanja as st
            where (`kolicinaInventure`>0 or stanje>0)
            and proda=:kodPoslovnice
            and (vrstaProdaje=:vrstaProdaje or trim(:vrstaProdaje)='')
            group by proda, kodRobe, vrstaProdaje
        ) as s
        join maticna_robe as m on m.kodRobe=s.kodRobe
        where s.cijena>0
        and (vrstaProdaje=:vrstaProdaje or trim(:vrstaProdaje)='')
        and (s.kodRobe=:kodRobe or trim(:kodRobe)='')
        and not exists
        (
            select * from posebni_cjenik as pc
            where pc.oznakaCjenika=:oznakaCjenika and pc.kodPoslovnice=:kodPoslovnice and pc.kodPartnera=:kodPartnera
            and (pc.vrstaProdaje=:vrstaProdaje or trim(:vrstaProdaje)='')
            and pc.`kodRobe`=s.`kodRobe` and pc.`vrstaProdaje`=s.`vrstaProdaje`
        )
        )            
        ";
        else    
        $query = "
        insert into posebni_cjenik
        (
        select :kodPoslovnice, :oznakaCjenika, :kodPartnera,
        s.kodRobe, s.vrstaProdaje, 
        if(:posto=0, s.cijena, 
           round(if(:promjenaCijene='S', s.cijena - s.cijena*:posto/100, s.cijena + s.cijena*:posto/100 ),3)
        ) as cijena,
        now(), null, :email_user
        from 
        (
            select proda, kodRobe, vrstaProdaje, 
            -- prosječna cijena
            round(sum(cijena*if(stanje>0,stanje,kolicinaInventure))/sum(if(stanje>0,stanje,kolicinaInventure)),3) as cijena 
            from stanja as st
            where (`kolicinaInventure`>0 or stanje>0)
            and proda=:kodPoslovnice
            and (vrstaProdaje=:vrstaProdaje or trim(:vrstaProdaje)='')
            group by proda, kodRobe, vrstaProdaje
        ) as s
        join maticna_robe as m on m.kodRobe=s.kodRobe
        where s.cijena>0
        and (vrstaProdaje=:vrstaProdaje or trim(:vrstaProdaje)='')
        and (kodGrupe=:kodGrupe or trim(:kodGrupe)='')
        and not exists
        (
            select * from posebni_cjenik as pc
            where pc.oznakaCjenika=:oznakaCjenika and pc.kodPoslovnice=:kodPoslovnice and pc.kodPartnera=:kodPartnera
            and (pc.vrstaProdaje=:vrstaProdaje or trim(:vrstaProdaje)='')
            and pc.`kodRobe`=s.`kodRobe` and pc.`vrstaProdaje`=s.`vrstaProdaje`
        )
        )            
        ";
        try {
            $statement = $db->prepare($query);
            $statement->bindValue(':oznakaCjenika', $oznakaCjenika);
            $statement->bindValue(':kodPoslovnice', $proda);
            $statement->bindValue(':kodPartnera', $kodPartnera);
            $statement->bindValue(':kodPartnera', $kodPartnera);
            if(trim($kodRobe)!='')
                $statement->bindValue(':kodRobe', $kodRobe);
            else    
                $statement->bindValue(':kodGrupe', $kodGrupe);
            $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
            $statement->bindValue(':posto', $posto);
            $statement->bindValue(':promjenaCijene', $promjenaCijene);
            $statement->bindValue(':email_user', $email_user);
            $statement->execute();
            $dodanoUCjenik = $statement->rowCount();
            $statement->closeCursor();
            unset($statement);
        } catch (PDOException $e) {
            $error_message = 'Kreiramje cjenika iz stanja:'.$e->getMessage();
            display_db_error($error_message);
        }
        
    }
    
    /*
    $query = "
        select pc.*, m.nazivRobe, m.jedinicaMjere, m.kodGrupe, round(pc.cijena*(1+PDV/100) ,3) as cijenaSPDV
        from posebni_cjenik as pc
        join maticna_robe as m on m.`kodRobe`=pc.`kodRobe`
        join porezi as p on p.poreznaGrupa=m.poreznaGrupa
        where oznakaCjenika=:oznakaCjenika and kodPoslovnice=:kodPoslovnice and kodPartnera=:kodPartnera
        and (vrstaProdaje=:vrstaProdaje or trim(:vrstaProdaje)='')
        and (kodGrupe=:kodGrupe or trim(:kodGrupe)='')
        LIMIT :od, :koliko
        ";
    $statement = $db->prepare($query);
    $statement->bindValue(':oznakaCjenika', $oznakaCjenika);
    $statement->bindValue(':kodPoslovnice', $proda);
    $statement->bindValue(':kodPartnera', $kodPartnera);
    $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
    $statement->bindValue(':kodGrupe', $kodGrupe);

    $statement->bindValue(':od', $stavkaOd-1, PDO::PARAM_INT);
    $statement->bindValue(':koliko', $stavkaDo - ($stavkaOd-1), PDO::PARAM_INT);
    $statement->execute();
    $zapisi = $statement->fetchAll();
    $statement->closeCursor();
    unset($statement);
     */
    //if($obrisano>0 or $dodanoUCjenik>0)
        //$_SESSION['poruka']= ($obrisano>0 ? 'Obrisano zapisa:'.$obrisano.'. ':'').($dodanoUCjenik>0 ? 'Dodano zapisa u cjenik:'.$dodanoUCjenik:'');
    //return $zapisi;   

    if($obrisano>0 or $dodanoUCjenik>0)
        $poruka= ($obrisano>0 ? 'Obrisano zapisa:'.$obrisano.'. ':'').($dodanoUCjenik>0 ? 'Dodano zapisa u cjenik:'.$dodanoUCjenik:'');
    else 
        $poruka='';
   
    return $poruka;   
    
}

function get_nazivi_cjenika($oznakaCjenika) {
    global $db;
    $query = 'SELECT * FROM nazivi_cjenika WHERE oznakaCjenika = :oznakaCjenika';
    $statement = $db->prepare($query);
    $statement->bindValue(':oznakaCjenika', $oznakaCjenika);
    $statement->execute();
    $zapis = $statement->fetch();
    $statement->closeCursor();
    return $zapis;   
}

function get_nazivi_cjenika_sve() {
    global $db;
    $query = 'SELECT * FROM nazivi_cjenika';
    $statement = $db->prepare($query);
    $statement->execute();
    $zapis = $statement->fetchAll();
    $statement->closeCursor();
    return $zapis;   
}

function get_popis_cjenika() {
    global $db;
    $query = "
        select distinct pc.kodPoslovnice, pc.oznakaCjenika, nc.nazivCjenika, pc.kodPartnera 
        from posebni_cjenik as pc
        left outer join nazivi_cjenika as nc on nc.oznakaCjenika= pc.oznakaCjenika
        ";
    $statement = $db->prepare($query);
    $statement->execute();
    $zapis = $statement->fetchAll();
    $statement->closeCursor();
    return $zapis;   
}

function add_nazivi_cjenika($oznakaCjenika, $nazivCjenika, $primjenaCjenika) {
    global $db;
    $email_user = $_SESSION['admin']['email'];
    $query = '
    INSERT INTO nazivi_cjenika
         ( oznakaCjenika,  nazivCjenika,  primjenaCjenika, datumOtvaranja, tkoJeIzmjenio)
    VALUES
         (:oznakaCjenika, :nazivCjenika, :primjenaCjenika,  NOW(), :email_user )';
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':oznakaCjenika', $oznakaCjenika);
        $statement->bindValue(':nazivCjenika', $nazivCjenika);
        $statement->bindValue(':primjenaCjenika', $primjenaCjenika);
        $statement->bindValue(':email_user', $email_user);
        $statement->execute();
        $statement->closeCursor();
        return $oznakaCjenika;
    } catch (PDOException $e) {
        $error_message = 'kreiranje naziva cjenika:'.$e->getMessage();
        display_db_error($error_message);
    }
    
}

function update_nazivi_cjenika($oznakaCjenika, $nazivCjenika) {
    global $db;
    $email_user = $_SESSION['admin']['email'];
    $query = "
    UPDATE nazivi_cjenika
    SET nazivCjenika=:nazivCjenika, 
        datumIzmjene=NOW(), 
        tkoJeIzmjenio=:email_user
    WHERE oznakaCjenika=:oznakaCjenika
    ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':oznakaCjenika', $oznakaCjenika);
        $statement->bindValue(':nazivCjenika', $nazivCjenika);
        $statement->bindValue(':email_user', $email_user);
        $statement->execute();
        $statement->closeCursor();
        return $oznakaCjenika;
    } catch (PDOException $e) {
        $error_message = 'iznjna naziva cjenika:'.$e->getMessage();
        display_db_error($error_message);
    }
    
}

function delete_posebni_cjenik($oznakaCjenika, $proda, $kodPartnera, $kodGrupe, $kodRobe, $vrstaProdaje) {
    global $db;
    if(trim($kodRobe)!='')
        $query = 
        "DELETE FROM posebni_cjenik 
        where oznakaCjenika=:oznakaCjenika and kodPoslovnice=:kodPoslovnice and kodPartnera=:kodPartnera
        and vrstaProdaje=:vrstaProdaje and kodRobe=:kodRobe
        ";
    else    
        $query = 
        "DELETE pc FROM posebni_cjenik as pc
        left outer join maticna_robe as m on m.`kodRobe`=pc.`kodRobe`
        where oznakaCjenika=:oznakaCjenika and kodPoslovnice=:kodPoslovnice and kodPartnera=:kodPartnera
        and (vrstaProdaje=:vrstaProdaje or trim(:vrstaProdaje)='')
        and (kodGrupe=:kodGrupe or trim(:kodGrupe)='')
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':oznakaCjenika', $oznakaCjenika);
        $statement->bindValue(':kodPoslovnice', $proda);
        $statement->bindValue(':kodPartnera', $kodPartnera);
        $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
        if(trim($kodRobe)!='')
            $statement->bindValue(':kodRobe', $kodRobe);
        else
            $statement->bindValue(':kodGrupe', $kodGrupe);
        $statement->execute();
        $rowCount = $statement->rowCount();
        $statement->closeCursor();
        unset($statement);
        //return $rowCount;
    } catch (PDOException $e) {
        $error_message = 'Brisanje cjenika:'.$e->getMessage();
        display_db_error($error_message);
    }   
    
    $query = "SELECT count(*) FROM posebni_cjenik where oznakaCjenika=:oznakaCjenika ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':oznakaCjenika', $oznakaCjenika);
        $statement->execute();
        $r = $statement->fetch();
        $statement->closeCursor();
        unset($statement);
    } catch (PDOException $e) {
        $error_message = 'Kontrola cjenika:'.$e->getMessage();
        display_db_error($error_message);
    }
    
    if(intval($r[0])==0) {
        // u cjeniku nema više slogova, možemo brisati naziv cjenika 
        $query = "DELETE FROM nazivi_cjenika where oznakaCjenika=:oznakaCjenika ";
        try {
            $statement = $db->prepare($query);
            $statement->bindValue(':oznakaCjenika', $oznakaCjenika);
            $statement->execute();
            $statement->closeCursor();
            unset($statement);
        } catch (PDOException $e) {
            $error_message = 'Brisanje naziva cjenika:'.$e->getMessage();
            display_db_error($error_message);
        }
    }
    return $rowCount;
}

function update_robu_u_cjeniku($oznakaCjenika, $proda, $kodPartnera, $kodRobe, $vrstaProdaje, $novaCijena) {
    global $db;
    $query = 
        "UPDATE posebni_cjenik 
         SET cijena=:novaCijena
        where oznakaCjenika=:oznakaCjenika and kodPoslovnice=:kodPoslovnice and kodPartnera=:kodPartnera
        and vrstaProdaje=:vrstaProdaje and kodRobe=:kodRobe 
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':oznakaCjenika', $oznakaCjenika);
        $statement->bindValue(':kodPoslovnice', $proda);
        $statement->bindValue(':kodPartnera', $kodPartnera);
        $statement->bindValue(':vrstaProdaje', $vrstaProdaje);
        $statement->bindValue(':novaCijena',$novaCijena);
        $statement->bindValue(':kodRobe', $kodRobe);
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = 'Promjena cijene:'.$e->getMessage();
        display_db_error($error_message);
    }    
    
}
?>
