<?php
function get_tarifni_brojevi() {
    global $db;
    $query = 'SELECT * FROM tarifni_brojevi ORDER BY tarifniBroj'; 
	try {
        $statement = $db->prepare($query);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function get_tarifni_broj($tarifniBroj) {
    global $db;
    $query = '
        SELECT *
        FROM tarifni_brojevi
        WHERE tarifniBroj = :tarifniBroj';
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':tarifniBroj', $tarifniBroj);
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function add_tarifni_broj($slog) {
    global $db;
	$email_user = $_SESSION['admin']['email'];
    $query = 'INSERT INTO tarifni_brojevi
                 (tarifniBroj, nazivTarifnogBroja, vrstaArtikla, datumOtvaranja, tkoJeIzmjenio)
              VALUES
                 (:tarifniBroj, :nazivTarifnogBroja, :vrstaArtikla, NOW(), :email_user )';
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':tarifniBroj', $slog['tarifniBroj']);
        $statement->bindValue(':vrstaArtikla', $slog['vrstaArtikla']);
        $statement->bindValue(':nazivTarifnogBroja', $slog['nazivTarifnogBroja']);       
        $statement->bindValue(':email_user', $email_user);
        $statement->execute();
        $statement->closeCursor();      
        return $slog['tarifniBroj'];
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function update_tarifni_broj($slog, $slogIzBaze) {
    global $db;
	$email_user = $_SESSION['admin']['email'];
    $query = '
        UPDATE tarifni_brojevi
        SET nazivTarifnogBroja = :nazivTarifnogBroja,           
            vrstaArtikla = :vrstaArtikla,
            datumIzmjene = NOW(),
            tkoJeIzmjenio = :email_user
        WHERE tarifniBroj = :tarifniBroj';
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':tarifniBroj', $slog['tarifniBroj']);
        $statement->bindValue(':nazivTarifnogBroja', $slog['nazivTarifnogBroja']);
        $statement->bindValue(':vrstaArtikla', $slog['vrstaArtikla']);
        $statement->bindValue(':email_user', $email_user); 
        $statement->execute();
        $statement->closeCursor();      
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }

    if(trim($slog['vrstaArtikla'])!=trim($slogIzBaze['vrstaArtikla'])) {
        $query = '
            UPDATE maticna_robe
            SET vrstaArtikla = :vrstaArtikla,
                datumIzmjene = NOW(),
                tkoJeIzmjenio = :email_user
            WHERE tarifniBroj = :tarifniBroj';
        try {
            $statement = $db->prepare($query);
            $statement->bindValue(':tarifniBroj', $slog['tarifniBroj']);
            $statement->bindValue(':vrstaArtikla', $slog['vrstaArtikla']);
            $statement->bindValue(':email_user', $email_user); 
            $statement->execute();
            $statement->closeCursor();      
        } catch (PDOException $e) {
            $error_message = $e->getMessage();
            display_db_error($error_message);
        }
    }
    
}

function delete_tarifni_broj($tarifniBroj) {
    global $db;
    $query = 'DELETE FROM tarifni_brojevi WHERE tarifniBroj = :tarifniBroj';
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':tarifniBroj', $tarifniBroj);
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

?>